@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.15 2005/09/27 19:14:29 lhoward Exp $ */
+/*	$Id: HylaFAXServer.h,v 1.16 2006/03/27 21:36:28 aidan Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -353,7 +353,7 @@ protected:
     bool checkUser(const char*);
     bool checkuser(FILE*, const char *name);
     bool checkuser(const char *name);
-    void login(void);
+    void login(int code);
     void end_login(void);
     virtual void dologout(int status);
     const char* fixPathname(const char* file);
