@@ -1,4 +1,4 @@
-/*	$Id: FaxClient.h,v 1.6 2005/03/14 18:06:07 lhoward Exp $ */
+/*	$Id: FaxClient.h,v 1.7 2006/01/30 21:40:49 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -63,7 +63,8 @@ public:
         FORM_PS   = 1,		// PostScript Level I
         FORM_PS2  = 2,		// PostScript Level II
         FORM_TIFF = 3,		// TIFF
-        FORM_PCL  = 4		// HP PCL5
+        FORM_PCL  = 4,		// HP PCL5
+        FORM_PDF  = 5		// Portable Document Format
     };
     enum {
         TZ_GMT	  = 1,		// use GMT timezone for time values
